Module beamlit.functions.common
===============================
Decorators for creating function tools with Beamlit and LangChain integration.

Functions
---------

`get_functions(remote_functions: list[str] | None = None, client: beamlit.client.AuthenticatedClient | None = None, dir: str | None = None, chain: list[beamlit.models.agent_chain.AgentChain] | None = None, remote_functions_empty: bool = True, from_decorator: str = 'function', warning: bool = True)`
: